@@ -18,7 +18,7 @@
 */
 
 #include "configmodule.h"
-#include "transportmanagementwidget.h"
+#include "widgets/transportmanagementwidget.h"
 
 #include <KPluginFactory>
 #include <KPluginLoader>
@@ -32,7 +32,7 @@ K_PLUGIN_FACTORY(MailTransportConfigFactory, registerPlugin<ConfigModule>();)
 ConfigModule::ConfigModule(QWidget *parent, const QVariantList &args) :
     KCModule(parent, args)
 {
-    setButtons(Q_NULLPTR);
+    setButtons(nullptr);
     QVBoxLayout *l = new QVBoxLayout(this);
     l->setMargin(0);
     TransportManagementWidget *tmw = new TransportManagementWidget(this);
